@@ -59,10 +59,6 @@ def print_timing(func):
 # i18n
 gettext.install("mintinstall", "/usr/share/linuxmint/locale")
 
-# i18n for menu item
-menuName = _("Software Manager")
-menuComment = _("Install new applications")
-
 architecture = commands.getoutput("uname -a")
 if (architecture.find("x86_64") >= 0):
     import ctypes
@@ -79,7 +75,12 @@ else:
 
 gtk.gdk.threads_init()
 
-COMMERCIAL_APPS = ["chromium-browser"]
+COMMERCIAL_APPS = ["chromium-browser", "chromium-browser-l10n", "chromium-codecs-ffmpeg", 
+                  "chromium-codecs-ffmpeg-extra", "chromium-codecs-ffmpeg-extra", 
+                  "chromium-browser-dbg", "chromium-chromedriver", "chromium-chromedriver-dbg"]
+
+# List of packages which are either broken or do not install properly in mintinstall
+BROKEN_PACKAGES = ['pepperflashplugin-nonfree']
 
 def get_dbus_bus():
    bus = dbus.SystemBus()
@@ -725,7 +726,7 @@ class Application():
         try:
             prefs["search_while_typing"] = (config['search']['search_while_typing'] == "True")
         except:
-            prefs["search_while_typing"] = True
+            prefs["search_while_typing"] = False
 
         #External browser
         try:
@@ -934,8 +935,7 @@ class Application():
 
         if (destination == "search"):
             self.notebook.set_current_page(self.PAGE_SEARCH)
-        else:
-            self.searchentry.set_text("")
+        else:            
             self._search_in_category = self.root_category
             if isinstance(destination, Category):
                 self._search_in_category = destination
@@ -944,6 +944,7 @@ class Application():
                         self.notebook.set_current_page(self.PAGE_MIXED)
                     else:
                         self.notebook.set_current_page(self.PAGE_CATEGORIES)
+                        self.searchentry.set_text("")
                 else:
                     self.notebook.set_current_page(self.PAGE_PACKAGES)
             elif isinstance(destination, Package):
@@ -1020,7 +1021,8 @@ class Application():
             if package.pkg.is_installed:
                 self.apt_client.remove_package(package.pkg.name)
             else:
-                self.apt_client.install_package(package.pkg.name)
+                if package.pkg.name not in BROKEN_PACKAGES:
+                    self.apt_client.install_package(package.pkg.name)
     
     def on_screenshot_clicked(self, url):
         package = self.current_package
@@ -1344,7 +1346,7 @@ class Application():
         
         for package in packages_list:
             
-            if package.name in COMMERCIAL_APPS:
+            if (not searchTree and package.name in COMMERCIAL_APPS):
                 continue
             
             iter = model_applications.insert_before(None, None)
@@ -1370,9 +1372,9 @@ class Application():
                     color = "#AA5555"
                 elif package.score > 0:
                     color = "#55AA55"
-                draw.text((34, 2), str(package.score), font=sans26, fill="#AAAAAA")
-                draw.text((33, 1), str(package.score), font=sans26, fill="#555555")                 
-                draw.text((32, 0), str(package.score), font=sans26, fill=color)
+                draw.text((87, 9), str(package.score), font=sans26, fill="#AAAAAA")
+                draw.text((86, 8), str(package.score), font=sans26, fill="#555555")
+                draw.text((85, 7), str(package.score), font=sans26, fill=color)
                 draw.text((13, 33), u"%s" % (_("%d reviews") % package.num_reviews), font=sans10, fill="#555555")
                 
                 model_applications.set_value(iter, 2, convertImageToGtkPixbuf(im))
@@ -1381,6 +1383,7 @@ class Application():
     
     @print_timing
     def show_category(self, category):
+        self.searchentry.set_text("")
         self._search_in_category = category
         # Load subcategories
         if len(category.subcategories) > 0:
@@ -1670,7 +1673,7 @@ class Application():
 
     @print_timing
     def show_package(self, package, tree):
-
+        self.searchentry.set_text("")
         self.current_package = package
                 
         # Load package info
@@ -1718,10 +1721,14 @@ class Application():
 
         impacted_packages = []    
         pkg = self.cache[package.name]
-        if package.pkg.is_installed:
-            pkg.mark_delete(True, True)
-        else:
-            pkg.mark_install()
+        try:
+            if package.pkg.is_installed:
+                pkg.mark_delete(True, True)
+            else:
+                pkg.mark_install()
+        except:
+            if pkg.name not in BROKEN_PACKAGES:
+                BROKEN_PACKAGES.append(pkg.name)            
     
         changes = self.cache.get_changes()
         for pkg in changes:
@@ -1789,11 +1796,18 @@ class Application():
             subs['action_button_description'] = _("Installed")
             subs['iconstatus'] = "/usr/lib/linuxmint/mintInstall/data/installed.png"
         else:
-            subs['action_button_label'] = _("Install")
-            subs['action_button_value'] = "install"
-            subs['version'] = package.pkg.candidate.version
-            subs['action_button_description'] = _("Not installed")
-            subs['iconstatus'] = "/usr/lib/linuxmint/mintInstall/data/available.png"
+            if package.pkg.name in BROKEN_PACKAGES:           
+                subs['action_button_label'] = _("Not available")
+                subs['action_button_value'] = "remove"
+                subs['version'] = package.pkg.candidate.version
+                subs['action_button_description'] = _("Please use apt-get to install this package.")
+                subs['iconstatus'] = "/usr/lib/linuxmint/mintInstall/data/available.png"
+            else:
+                subs['action_button_label'] = _("Install")
+                subs['action_button_value'] = "install"
+                subs['version'] = package.pkg.candidate.version
+                subs['action_button_description'] = _("Not installed")
+                subs['iconstatus'] = "/usr/lib/linuxmint/mintInstall/data/available.png"
 
         if package.num_reviews > 0:
             sans26 = ImageFont.truetype(self.FONT, 26)
@@ -1806,9 +1820,9 @@ class Application():
                 color = "#AA5555"
             elif package.score > 0:
                 color = "#55AA55"
-            draw.text((34, 2), str(package.score), font=sans26, fill="#AAAAAA")
-            draw.text((33, 1), str(package.score), font=sans26, fill="#555555")
-            draw.text((32, 0), str(package.score), font=sans26, fill=color)         
+            draw.text((87, 9), str(package.score), font=sans26, fill="#AAAAAA")
+            draw.text((86, 8), str(package.score), font=sans26, fill="#555555")
+            draw.text((85, 7), str(package.score), font=sans26, fill=color)
             draw.text((13, 33), u"%s" % (_("%d reviews") % package.num_reviews), font=sans10, fill="#555555")
             tmpFile = tempfile.NamedTemporaryFile(delete=True)
             im.save (tmpFile.name + ".png")
